Capability

Struct Capability 

pub struct Capability;
Capability string constants.

Organized by the minimum tier required to hold each capability. Orthogonal capabilities (vpn.handshake, relay.reject) are not included in any tier and require explicit grants.

Implementations

Source

impl Capability

pub const CHAT_SEND: &str = "chat.send"

pub const CHAT_RECEIVE: &str = "chat.receive"

pub const PAGE_BROWSE: &str = "page.browse"

pub const RPC_PING: &str = "rpc.ping"

pub const RPC_STATUS: &str = "rpc.status"

pub const RELAY_REQUEST: &str = "relay.request"

pub const RELAY_LIST: &str = "relay.list"

pub const RELAY_TEARDOWN: &str = "relay.teardown"

pub const RELAY_ACCEPT: &str = "relay.accept"

pub const RPC_INBOX_READ: &str = "rpc.inbox_read"

pub const WEB_READ: &str = "web.read"

pub const RPC_CONFIG_UPDATE: &str = "rpc.config_update"

pub const TERMINAL_RESTRICTED: &str = "terminal.restricted"

pub const WEB_WRITE: &str = "web.write"

pub const RELAY_REQUEST_PERMANENT: &str = "relay.request_permanent"

pub const RELAY_ACCEPT_PERMANENT: &str = "relay.accept_permanent"

pub const RELAY_PRIORITIZE: &str = "relay.prioritize"

pub const RELAY_BRIDGE: &str = "relay.bridge"

pub const RPC_EXEC: &str = "rpc.exec"

pub const RPC_REBOOT: &str = "rpc.reboot"

pub const RPC_SELF_UPDATE: &str = "rpc.self_update"

pub const TERMINAL_FULL: &str = "terminal.full"

pub const ADAPTER_PROVISION: &str = "adapter.provision"

pub const RELAY_ADMIN: &str = "relay.admin"

pub const TUNNEL_STATUS: &str = "tunnel.status"

View tunnel status and list active tunnels (Peer)

pub const TUNNEL_ESTABLISH: &str = "tunnel.establish"

Initiate or accept tunnel establishment (Operator)

pub const TUNNEL_TEARDOWN: &str = "tunnel.teardown"

Tear down an active tunnel (Operator)

pub const VPN_HANDSHAKE: &str = "vpn.handshake"

pub const RELAY_REJECT: &str = "relay.reject"

pub const I2P_PROXY: &str = "i2p.proxy"

pub const AETHER_DELEGATE: &str = "aether.delegate"

pub const AETHER_QUERY: &str = "aether.query"

pub const AETHER_REPORT: &str = "aether.report"